@@ -1,4 +1,4 @@
-/*	$Id: kcgi.h,v 1.151 2020/04/10 12:58:29 kristaps Exp $ */
+/*	$Id: kcgi.h,v 1.157 2020/07/21 12:59:17 kristaps Exp $ */
 /*
  * Copyright (c) 2012, 2014--2018 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -53,7 +53,7 @@
 /*
  * Build version.
  */
-#define	KCGI_VBUILD	0
+#define	KCGI_VBUILD	2
 
 /*
  * Version string of major.minor.build (as a literal string).
@@ -593,8 +593,15 @@ enum kcgi_err	 khttp_fcgi_free(struct kfcgi *);
 void		 khttp_fcgi_child_free(struct kfcgi *);
 int		 khttp_fcgi_test(void);
 
-#define		KUTIL_EPOCH2TM(_tt, _tm) \
-		kutil_epoch2tmvals((_tt), \
+void		 khttp_epoch2datetime(int64_t, int64_t *, int64_t *,
+			int64_t *, int64_t *, int64_t *, int64_t *,
+			int64_t *, int64_t *);
+char		*khttp_epoch2str(int64_t, char *, size_t);
+char		*khttp_epoch2ustr(int64_t, char *, size_t);
+int		 khttp_epoch2tms(int64_t, int *, int *, int *, 
+			int *, int *, int *, int *, int *);
+#define		 KHTTP_EPOCH2TM(_tt, _tm) \
+		 khttp_epoch2tms((_tt), \
 			&(_tm)->tm_sec, \
 			&(_tm)->tm_min, \
 			&(_tm)->tm_hour, \
@@ -602,17 +609,11 @@ int		 khttp_fcgi_test(void);
 			&(_tm)->tm_mon, \
 			&(_tm)->tm_year, \
 			&(_tm)->tm_wday, \
-			&(_tm)->tm_yday);
-void		 kutil_epoch2tmvals(int64_t, int *, int *, int *, 
-			int *, int *, int *, int *, int *);
-char		*kutil_epoch2str(int64_t, char *, size_t);
-char		*kutil_epoch2utcstr(int64_t, char *, size_t);
-int64_t	 	 kutil_date2epoch(int64_t, int64_t, int64_t);
-int	 	 kutil_date_check(int64_t, int64_t, int64_t);
-int64_t	 	 kutil_datetime2epoch(int64_t, int64_t, int64_t,
-			int64_t, int64_t, int64_t);
-int	 	 kutil_datetime_check(int64_t, int64_t, int64_t,
-			int64_t, int64_t, int64_t);
+			&(_tm)->tm_yday)
+int	 	 khttp_datetime2epoch(int64_t *, int64_t, int64_t,
+			int64_t, int64_t, int64_t, int64_t);
+int	 	 khttp_date2epoch(int64_t *, int64_t, int64_t,
+			int64_t);
 
 char 		*khttp_urlabs(enum kscheme, const char *, 
 			uint16_t, const char *, ...);
@@ -630,22 +631,6 @@ char		*khttp_vurlpart(const char *,
 char		*khttp_vurlpartx(const char *,
 			const char *, const char *, va_list);
 
-char		*kutil_urlabs(enum kscheme, const char *, 
-			uint16_t, const char *)
-			__attribute((deprecated));
-enum kcgi_err	 kutil_urldecode(const char *, char **)
-			__attribute((deprecated));
-enum kcgi_err	 kutil_urldecode_inplace(char *)
-			__attribute((deprecated));
-char		*kutil_urlencode(const char *)
-			__attribute((deprecated));
-char		*kutil_urlpart(struct kreq *, const char *,
-			const char *, const char *, ...)
-			__attribute((deprecated));
-char		*kutil_urlpartx(struct kreq *, const char *,
-			const char *, const char *, ...)
-			__attribute((deprecated));
-
 void		 kutil_invalidate(struct kreq *, struct kpair *);
 
 int		 kutil_openlog(const char *);
@@ -714,6 +699,50 @@ extern const char *const	 kmethods[KMETHOD__MAX];
 extern const struct kmimemap	 ksuffixmap[];
 extern const char *const	 ksuffixes[KMIME__MAX];
 
+/* DEPRECATED FUNCTIONS AND MACROS. */
+
+#define		 KUTIL_EPOCH2TM(_tt, _tm) \
+		 kutil_epoch2tmvals((_tt), \
+			&(_tm)->tm_sec, \
+			&(_tm)->tm_min, \
+			&(_tm)->tm_hour, \
+			&(_tm)->tm_mday, \
+			&(_tm)->tm_mon, \
+			&(_tm)->tm_year, \
+			&(_tm)->tm_wday, \
+			&(_tm)->tm_yday)
+void		 kutil_epoch2tmvals(int64_t, int *, int *, int *, 
+			int *, int *, int *, int *, int *)
+			__attribute__((deprecated));
+char		*kutil_epoch2str(int64_t, char *, size_t)
+			__attribute__((deprecated));
+char		*kutil_epoch2utcstr(int64_t, char *, size_t)
+			__attribute__((deprecated));
+int64_t	 	 kutil_date2epoch(int64_t, int64_t, int64_t)
+			__attribute__((deprecated));
+int	 	 kutil_date_check(int64_t, int64_t, int64_t)
+			__attribute__((deprecated));
+int64_t	 	 kutil_datetime2epoch(int64_t, int64_t, int64_t,
+			int64_t, int64_t, int64_t)
+			__attribute__((deprecated));
+int	 	 kutil_datetime_check(int64_t, int64_t, int64_t,
+			int64_t, int64_t, int64_t)
+			__attribute__((deprecated));
+char		*kutil_urlabs(enum kscheme, const char *, 
+			uint16_t, const char *)
+			__attribute__((deprecated));
+enum kcgi_err	 kutil_urldecode(const char *, char **)
+			__attribute__((deprecated));
+enum kcgi_err	 kutil_urldecode_inplace(char *)
+			__attribute__((deprecated));
+char		*kutil_urlencode(const char *)
+			__attribute__((deprecated));
+char		*kutil_urlpart(struct kreq *, const char *,
+			const char *, const char *, ...)
+			__attribute__((deprecated));
+char		*kutil_urlpartx(struct kreq *, const char *,
+			const char *, const char *, ...)
+			__attribute__((deprecated));
 __END_DECLS
 
 #endif /*!KCGI_H*/
